EasyToastMessage class

A utility class to show a customizable toast message. The toast can be customized with different colors, icons, fonts, and positions.

Constructors

EasyToastMessage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show(BuildContext context, String message, {Color backgroundColor = Colors.white, Color textColor = Colors.black, IconData icon = Icons.info_outline, Color iconColor = Colors.black, double fontSize = 16.0, String fontFamily = 'Poppins', double borderRadius = 15.0, double verticalPadding = 12.0, double horizontalPadding = 24.0, Duration duration = const Duration(seconds: 3), Alignment alignment = Alignment.bottomCenter, double offset = 50.0, Color shadowColor = Colors.black, double shadowSpreadRadius = 2.0, double shadowBlurRadius = 5.0, Offset shadowOffset = const Offset(0, 3)}) → void
Displays a toast message.